Welcome to analphipy's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   notebooks/usage
   api_autosummary
   contributing
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
